<?php
/*
 File: clientraww.php

 Purpose: provide a current conditions and icon from a WeeWX running the WD bridge software

 Configure a metar in $SITE['conditionsMETAR'] entry.
 Set $SITE['overrideRain'] = true; to enable local rain to override sky conditions from metar.
 
 Author: Ken True - webmaster@saratoga-weather.org

//Version 1.00 - 14-May-2021

*/
// --------------------------------------------------------------------------

// allow viewing of generated source

if (isset($_REQUEST["sce"]) and strtolower($_REQUEST["sce"]) == "view" ) {
//--self downloader --
   $filenameReal = __FILE__;
   $download_size = filesize($filenameReal);
   header("Pragma: public");
   header("Cache-Control: private");
   header("Cache-Control: no-cache, must-revalidate");
   header("Content-type: text/plain");
   header("Accept-Ranges: bytes");
   header("Content-Length: $download_size");
   header("Connection: close");
   
   readfile($filenameReal);
   exit;
}
#-------------------------------------------------------------------------------------
# function processed WD variables
#-------------------------------------------------------------------------------------
global $SITE,$Debug;
if(file_exists('Settings.php')) {include_once('Settings.php'); }
if(isset($SITE['WXtags'])) { include_once($SITE['WXtags']); }
if(isset($SITE['clientrawfile'])) {
	$crawfile = file_get_contents($SITE['clientrawfile']);
	if (strlen($crawfile) > 50) {
		$v = explode(' ',$crawfile);
	}
} else {
	$v = array();
}
if(isset($SITE['conditionsMETAR'])) { // override with METAR conditions for text and icon if requested.
	include_once("get-metar-conditions-inc.php");
	list($Currentsolardescription,$iconnumber) = mtr_conditions($SITE['conditionsMETAR'], $time, $sunrise, $sunset);
    if(isset($currentrainratehr) and 
      (!isset($SITE['overrideRain']) or (isset($SITE['overrideRain']) and $SITE['overrideRain'])) ) {
	  list($Currentsolardescription,$iconnumber) = 
	  WWX_RainRateIcon($Currentsolardescription,$iconnumber,$currentrainratehr,$uomrain,$time,$sunrise,$sunset);
		$v[48] = $iconnumber;
		$v[49] = str_replace(' ','_',$Currentsolardescription);
		$nclientraw = join(' ',$v);
		header('Content-type: text/plain;charset=ISO-8859-1');
		header('Last-modified: '.gmdate('r',filemtime($SITE['clientrawfile'])) );
		print $nclientraw;
    }
}

#-------------------------------------------------------------------------------------
# WeeWX support function - WWX_RainRateIcon
#-------------------------------------------------------------------------------------

function WWX_RainRateIcon($inText,$inIcon,$inRate,$inUOM,$time,$sunrise,$sunset,$lastRain='0000-00-00T00:00:00') {
   global $Debug;
   
/*
Rainfall intensity is classified according to the rate of precipitation:

    Light rain  rate is < 2.5 mm (0.098 in) per hour
    Moderate rain  rate is between 2.5 mm (0.098 in) - 7.6 mm (0.30 in) or 10 mm (0.39 in) per hour
    Heavy rain  rate is > 7.6 mm (0.30 in) per hour, or between 10 mm (0.39 in) and 50 mm (2.0 in) per hour
    Violent rain  rate is > 50 mm (2.0 in) per hour
*/	
   $Debug .= "<!-- WWX_RainRateIcon in='$inText' icon='$inIcon' rate='$inRate' uom='$inUOM' -->\n";
   $newText = '';  // assume no changes
   $newIcon = $inIcon;
   
   $rate = $inRate;
   if(preg_match('|in|i',$inUOM)) { // convert to mm/hr rate
     $rate = $inRate * 25.4;
   }
   
   if(substr($lastRain,0,4) <> '0000') {
	  if($rate < 0.001 and time()-strtotime($lastRain) < 30*60) {
		 $newText = 'Moderate Drizzle';
	  }
   }

   if ($rate > 0.0 and $rate < 2.5) { $newText = 'Light Rain'; }
   if ($rate >=2.5 and $rate < 7.6) { $newText = 'Moderate Rain'; }
   if ($rate >=7.6 and $rate < 50.0) { $newText = 'Heavy Rain'; }
   if ($rate >= 50.0)         { $newText = 'Violent Rain'; }
   
   if($newText <> '' or $rate == 0.0) {
	   if ($newText <> '' and $inText <> '') {$newText .= ', ';}
	   $newText .= 
	      preg_replace('/(Light|Moderate|Heavy|Violent|Extreme){0,1}\s*(Rain|Mist|Drizzle), /i','',$inText);
	   $newIcon = mtr_get_iconnumber ($time,$newText,$sunrise,$sunset); 
   } else {
	   $newText = $inText;
   }
   $Debug .= "<!-- WWX_RainRateIcon out='$newText' icon='$newIcon' rate='$rate' mm/hr -->\n";
   return(array($newText,$newIcon));
}

